/*
 *   ORXONOX - the hottest 3D action shooter ever to exist
 *                    > www.orxonox.net <
 *
 *
 *   License notice:
 *
 *   This program is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU General Public License
 *   as published by the Free Software Foundation; either version 2
 *   of the License, or (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 *   Author:
 *      Florian Zinggeler
 *
 */

#include "FlappyOrxHUDinfo.h"

#include "core/CoreIncludes.h"
#include "core/XMLPort.h"
#include "util/Convert.h"
#include "FlappyOrx.h"

namespace orxonox
{
    RegisterClass(FlappyOrxHUDinfo);

    FlappyOrxHUDinfo::FlappyOrxHUDinfo(Context* context) : OverlayText(context)
    {
        RegisterObject(FlappyOrxHUDinfo);

        this->FlappyOrxGame = nullptr;
        this->bShowLives_ = false;
        this->bShowLevel_ = true;
        this->bShowPoints_ = false;
        this->bShowMultiplier_ = false;
        this->bShowGameOver_ = false;
        this->sGameOverMessage_ = "";
    }

    void FlappyOrxHUDinfo::XMLPort(Element& xmlelement, XMLPort::Mode mode)
    {
        SUPER(FlappyOrxHUDinfo, XMLPort, xmlelement, mode);

        XMLPortParam(FlappyOrxHUDinfo, "showlives",     setShowLives,     getShowLives,     xmlelement, mode).defaultValues(false);
        XMLPortParam(FlappyOrxHUDinfo, "showpoints",    setShowPoints,    getShowPoints,    xmlelement, mode).defaultValues(false);
        XMLPortParam(FlappyOrxHUDinfo, "showmessage",   setShowMessage,   getShowMessage,   xmlelement, mode).defaultValues(false);
       
    
    }

    void FlappyOrxHUDinfo::tick(float dt)
    {
        SUPER(FlappyOrxHUDinfo, tick, dt);

        if (this->FlappyOrxGame)
        {
            if(not this->FlappyOrxGame->isDead()){
                if(this->bShowPoints_){
                    const std::string& points = "Score: "+multi_cast<std::string>(this->FlappyOrxGame->getPoints());
                    setTextSize(0.04);
                    setPosition(Vector2(0.14, 0.02));
                    this->setColour(ColourValue(1, 1, 1, 1));
                    this->setCaption(points);
                }
                else if(this->bShowGameOver_){
                    setTextSize(0);
                }
            }
            else{
                if(this->bShowPoints_){
                    setTextSize(0);
                }
                else if(this->bShowGameOver_){
                    std::string message = this->FlappyOrxGame->getDeathMessage();
                    setTextSize(0.1);
                    setPosition(Vector2(.5, .5));

                    setAlignment(OverlayText::Alignment::Center);
                    
                    this->setCaption(message);
                    this->setColour(ColourValue(1, 0, 0, 1));
                }
            }   
        }
    }

    void FlappyOrxHUDinfo::changedOwner()
    {
        SUPER(FlappyOrxHUDinfo, changedOwner);

        if (this->getOwner() && this->getOwner()->getGametype())
        {
            this->FlappyOrxGame = orxonox_cast<FlappyOrx*>(this->getOwner()->getGametype());
        }
        else
        {
            this->FlappyOrxGame = nullptr;
        }
    }
}
